@@ -1,3 +1,3 @@
 from .recorder import Recorder, FileRecorder
-from .consumer import Consumer
 from .filter import Filter
+from .consumer import Consumer, EventConsumer, ComplianceConsumer
