@@ -4,7 +4,6 @@ Used to maintain the current state of the stream.
 
 """
 import abc
-import collections
 import os
 
 
@@ -23,21 +22,21 @@ class Recorder(object):
 
 
 class FileRecorder(Recorder):
-    filename = None
+    filename: str
 
-    def __init__(self, filename):
+    def __init__(self, filename: str):
         super(FileRecorder, self).__init__()
         self.filename = filename
 
     def read_offset(self):
         if os.path.exists(self.filename):
-            f = open(self.filename, 'r')
+            f = open(self.filename, "r")
             offset = f.read().strip()
         else:
             offset = None
         return offset
 
-    def write_offset(self, offset):
-        f = open(self.filename, 'w')
+    def write_offset(self, offset: str):
+        f = open(self.filename, "w")
         f.write(offset)
         f.close()
